@@ -2,6 +2,8 @@ from .display_metrics_callback import DisplayMetricsCallback
 from .lr_logger import LrLogger
 from .epoch_num_logger import EpochNumLogger
 from .epoch_time_logger import EpochTimeLogger
+from .gpu_stats_logger import GpuStatsLogger
+from .system_stats_logger import SystemStatsLogger
 from .nil_callback import NilCallback
 from .earlystop_lr import EarlyStoppingLR
 
@@ -9,6 +11,8 @@ __all__ = [
     "LrLogger",
     "EpochNumLogger",
     "EpochTimeLogger",
+    "GpuStatsLogger",
+    "SystemStatsLogger",
     "NilCallback",
     "DisplayMetricsCallback",
     "EarlyStoppingLR",
